'''
LMS player
based on https://github.com/molobrakos/lms
'''

from urllib.parse import urlparse,urlunparse,unquote, quote
import logging
#from lms.server import LMSServer
from lmsmusly.utils import config

__version__ = '0.0.1'

_LOGGER = logging.getLogger(__name__)

class LMSPlayer:

	def __init__(self, server, player):
		self._server = server
		self._state = player

	def __str__(self):

		return '%s [%s] @ %s' % ( self.get_name(), self.get_player_id(), self.get_ip())

	def get_player_id(self):
		return self._state['playerid']

	def get_name(self):
		return self._state['name']

	def get_ip(self):
		return self._state.get('player_ip')

	def get_mode(self):
		return self._state.get('mode')

	def is_playing(self):
		return self.get_mode() == 'play'

	def is_stopped(self):
		return self.get_mode() == 'stop'

	def is_paused(self):
		return self.get_mode() == 'pause'

	def is_shuffle(self):
		return self._state.get('playlist_shuffle') == 1

	def query(self, *params):
		return self._server.query(*params, player=self.get_player_id())

	def update(self):
		tags = 'alu'  # artist, album, url
		response = self.query(
#			'status', '-', '1', 'tags:{tags}'
			'status', 0, config.LMS_MAXLEN, 'tags:{tags}'
			.format(tags=tags))

		if response is False:
			return

		'''
		try:
			self._state.update(response['playlist_loop'][0])
		except KeyError:
			pass

		try:
			self._state.update(response['remoteMeta'])
		except KeyError:
			pass
		'''
		self._state.update(response)

	def playlist_add( self, file):
		url = urlunparse( ('file', '', quote( file), '', '', '') )
		_LOGGER.debug( "playlist_add: url= {}".format( url))
		response = self.query('playlist', 'add', url)
	def playlist_delete_idx( self, idx):
		response = self.query('playlist', 'delete', idx)
#		_LOGGER.debug( "playlist_delete_idx: response= {}".format( repr(response)))

	def get_track_id(self):
		return self._state['id']
	def get_playlist(self):
		return self._state['playlist_loop']
	def get_playlist_len(self):
		return int( self._state['playlist_tracks'])
	def get_current_index(self):
		return int( self._state['playlist_cur_index'])
	def get_track(self, idx):
		return self._state['playlist_loop'][idx]
	def get_track_fileurl(self, idx):
#		_LOGGER.debug( "get_track_fileurl: idx= {} plslen={}".format( idx, len(self._state['playlist_loop'])))
		if len(self._state['playlist_loop']) -1 < idx:
			return None
		return unquote( urlparse( self._state['playlist_loop'][idx]['url']).path)

	def display(self, line2, line1="LMSmusly:", duration=3):
		if config.LMS_NOTIFICATIONS:
			response = self.query('display', line1, line2, duration )
			#_LOGGER.debug( "show: response= {}".format( repr(response)))
